.. meta::
    :description lang=en:
        Generate keywords for SEM campaigns on a massive scale. A Python
        function for generating a read-to-use table of keywords, ad groups,
        campaigns, and tags.

.. automodule:: advertools.kw_generate
   :members:
   :undoc-members:
   :show-inheritance:
